@@ -2,6 +2,6 @@ from distutils.core import setup
 
 setup(
     name='listprinter',
-    version='1.0.0',
+    version='1.3.0',
     py_modules=['listPrinter'],
-    author='ajogor')
+    author='ajagor')
